==> vmonere-0.1.0.tar.gz: vmonere-0.1.0/setup.py <==
#!/usr/bin/env python

from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
#with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
#    long_description = f.read()

setup(
      name='vmonere',
      
      # Versions should comply with PEP440.  For a discussion on single-sourcing
      # the version across setup.py and the project code, see
      # https://packaging.python.org/en/latest/development.html#single-sourcing-the-version
      version='0.1.0',
      
      description=('A high-level Python  CLI for virtual machine '
                   'monitoring'),
      long_description=('A high-level Python  CLI for cloud monitoring '
                        'It is used to monitor the real time usage of resources '),
      
      # The project's main homepage.
      url='http://dcsolvere.github.io/vmonere/',
      
      # Author details
      author='Dinesh Appavoo',
      author_email='dinesha.cit@gmail.com',
      
      # Choose your license
      license='MIT',
      
      # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
                   # How mature is this project? Common values are
                   #   3 - Alpha
                   #   4 - Beta
                   #   5 - Production/Stable
                   'Development Status :: 3 - Alpha',
                   
                   # Indicate who your project is intended for
                   'Intended Audience :: Developers',
                   'Topic :: Software Development :: Build Tools',
                   
                   # Pick your license as you wish (should match "license" above)
                   'License :: OSI Approved :: MIT License',
                   
                   # Specify the Python versions you support here. In particular, ensure
                   # that you indicate whether you support Python 2, Python 3 or both.
                   'Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 2.6',
                   'Programming Language :: Python :: 2.7',
                   ],
      
      # What does your project relate to?
      keywords='monitor',
      
      # You can just specify the packages manually here if your project is
      # simple. Or you can use find_packages().
      packages=find_packages(exclude=['docs']),
      
      # List run-time dependencies here.  These will be installed by pip when your
      # project is installed. For an analysis of "install_requires" vs pip's
      # requirements files see:
      # https://packaging.python.org/en/latest/technical.html#install-requires-vs-requirements-files
      install_requires=['pexpect','lockfile'],
      
      # List additional groups of dependencies here (e.g. development dependencies).
      # You can install these using the following syntax, for example:
      # $ pip install -e .[dev,test]
      extras_require = {
      'dev': ['check-manifest'],
      'test': ['coverage'],
      },
      
      # If there are data files included in your packages that need to be
      # installed, specify them here.  If using Python 2.6 or less, then these
      # have to be included in MANIFEST.in as well.
      package_data={
      'guest': ['*.txt'],
      'hostinfo': ['*.txt'],
      'usr_bin': ['*','*.*'],
      '': ['*.rst','*.socket','*.jar','*.java','*.c','*.sh','*.xml','*.pkl'],

      },
      
      # Although 'package_data' is the preferred approach, in some case you may
      # need to place data files outside of your packages.
      # see http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files
      # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
      data_files=[('/usr/bin', ['usr_bin/virtdc.py'])],
      
      # To provide executable scripts, use entry points in preference to the
      # "scripts" keyword. Entry points provide cross-platform support and allow
      # pip to create the appropriate form of executable for the target platform.
      entry_points={
      'console_scripts': [
                          'sample=sample:main',
                          ],
      },
      )

==> vmonere-0.1.1.tar.gz: vmonere-0.1.1/setup.py <==
#!/usr/bin/env python

from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
#with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
#    long_description = f.read()

setup(
      name='vmonere',
      
      # Versions should comply with PEP440.  For a discussion on single-sourcing
      # the version across setup.py and the project code, see
      # https://packaging.python.org/en/latest/development.html#single-sourcing-the-version
      version='0.1.1',
      
      description=('A high-level Python  CLI for virtual machine '
                   'monitoring'),
      long_description=open("README.rst").read(),
      
      # The project's main homepage.
      url='http://dcsolvere.github.io/vmonere/',
      
      # Author details
      author='Dinesh Appavoo',
      author_email='dinesha.cit@gmail.com',
      
      # Choose your license
      license='MIT',
      
      # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
                   # How mature is this project? Common values are
                   #   3 - Alpha
                   #   4 - Beta
                   #   5 - Production/Stable
                   'Development Status :: 3 - Alpha',
                   
                   # Indicate who your project is intended for
                   'Intended Audience :: Developers',
                   'Topic :: Software Development :: Build Tools',
                   
                   # Pick your license as you wish (should match "license" above)
                   'License :: OSI Approved :: MIT License',
                   
                   # Specify the Python versions you support here. In particular, ensure
                   # that you indicate whether you support Python 2, Python 3 or both.
                   'Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 2.6',
                   'Programming Language :: Python :: 2.7',
                   ],
      
      # What does your project relate to?
      keywords='monitor',
      
      # You can just specify the packages manually here if your project is
      # simple. Or you can use find_packages().
      packages=find_packages(exclude=['docs']),
      
      # List run-time dependencies here.  These will be installed by pip when your
      # project is installed. For an analysis of "install_requires" vs pip's
      # requirements files see:
      # https://packaging.python.org/en/latest/technical.html#install-requires-vs-requirements-files
      install_requires=['pexpect','lockfile'],
      
      # List additional groups of dependencies here (e.g. development dependencies).
      # You can install these using the following syntax, for example:
      # $ pip install -e .[dev,test]
      extras_require = {
      'dev': ['check-manifest'],
      'test': ['coverage'],
      },
      
      # If there are data files included in your packages that need to be
      # installed, specify them here.  If using Python 2.6 or less, then these
      # have to be included in MANIFEST.in as well.
      package_data={
      'guest': ['*.txt'],
      'hostinfo': ['*.txt'],
      'usr_bin': ['*','*.*'],
      '': ['*.rst','*.socket','*.jar','*.java','*.c','*.sh','*.xml','*.pkl'],

      },
      
      # Although 'package_data' is the preferred approach, in some case you may
      # need to place data files outside of your packages.
      # see http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files
      # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
      data_files=[('/usr/bin', ['usr_bin/virtdc.py'])],
      
      # To provide executable scripts, use entry points in preference to the
      # "scripts" keyword. Entry points provide cross-platform support and allow
      # pip to create the appropriate form of executable for the target platform.
      entry_points={
      'console_scripts': [
                          'sample=sample:main',
                          ],
      },
      )
